akhdefo_functions.Filter_PreProcess — akhdefo 2023 documentation

# akhdefo_functions.Filter_PreProcess

akhdefo_functions.Filter_PreProcess(unfiltered_folderPath='', UDM2_maskfolderPath='', outpath_dir='', Udm_Mask_Option=False)

  This program prepare and uses filters to balanace raster image brightness

  unfiltered_folderPath=r””

  UDM2_maskfolderPath=r””

  outpath_dir=r””

  Udm_Mask_Option=False if True the program uses planetlabs imagery unusable pixel mask to ignore and mask bad image pixels